trident_chemwidgets.tests.test_nbextension_path - Trident Chemwidgets - Docs v0.1

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# Source code for trident_chemwidgets.tests.test_nbextension_path

    #!/usr/bin/env python
    # coding: utf-8

    # Copyright (c) Trident Bioscience, Inc..
    # Distributed under the terms of the Modified BSD License.

    def test_nbextension_path():
        # Check that magic function can be imported from package root:
        from trident_chemwidgets import _jupyter_nbextension_paths
        # Ensure that it can be called without incident:
        path = _jupyter_nbextension_paths()
        # Some sanity checks:
        assert len(path) == 1
        assert isinstance(path[0], dict)